Documentation
¶
Index ¶
- type ResultsTable
- func (r *ResultsTable) AddProcessedBytes(sizeInBytes int64)
- func (r *ResultsTable) AddTotalBytes(sizeInBytes int64)
- func (r *ResultsTable) Done()
- func (r *ResultsTable) Lock()
- func (r *ResultsTable) ReportResult(offset int64, filename string, lic licenceinfo.LicenceInfoInterface)
- func (r *ResultsTable) SetPathToOutputCLFile(path string)
- func (r *ResultsTable) SetPathToOutputJsonFile(path string)
- func (r *ResultsTable) StartProgressPrinter()
- func (r *ResultsTable) Unlock()
- func (r *ResultsTable) WriteResultsToFile()
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ResultsTable ¶
type ResultsTable struct {
LicenceInfos []licenceinfo.LicenceInfoInterface
PathToOutputCLFile string
PathToOutputJsonFile string
// contains filtered or unexported fields
}
func NewResultsTable ¶
func NewResultsTable(debug bool) *ResultsTable
func (*ResultsTable) AddProcessedBytes ¶
func (r *ResultsTable) AddProcessedBytes(sizeInBytes int64)
AddProcessedBytes adds the processed bytes to the progress bar
func (*ResultsTable) AddTotalBytes ¶
func (r *ResultsTable) AddTotalBytes(sizeInBytes int64)
AddTotalBytes adds the total bytes to the progress bar
func (*ResultsTable) Done ¶
func (r *ResultsTable) Done()
Done writes the results to the output file and sets the done flag
func (*ResultsTable) Lock ¶
func (r *ResultsTable) Lock()
func (*ResultsTable) ReportResult ¶
func (r *ResultsTable) ReportResult(offset int64, filename string, lic licenceinfo.LicenceInfoInterface)
ReportResult reports a found LICKEY and adds it to the results table
func (*ResultsTable) SetPathToOutputCLFile ¶
func (r *ResultsTable) SetPathToOutputCLFile(path string)
SetPathToOutputFile sets the path to the output file
func (*ResultsTable) SetPathToOutputJsonFile ¶
func (r *ResultsTable) SetPathToOutputJsonFile(path string)
SetPathToOutputJsonFile sets the path to the output JSON file
func (*ResultsTable) StartProgressPrinter ¶
func (r *ResultsTable) StartProgressPrinter()
func (*ResultsTable) Unlock ¶
func (r *ResultsTable) Unlock()
func (*ResultsTable) WriteResultsToFile ¶
func (r *ResultsTable) WriteResultsToFile()
WriteResultsToFile writes the results to the output file
Click to show internal directories.
Click to hide internal directories.